rpms/wine/devel wine-fonts.patch, NONE, 1.1 wine-imagemagick-6.5.patch, NONE, 1.1 .cvsignore, 1.85, 1.86 sources, 1.86, 1.87 wine-notepad.desktop, 1.4, 1.5 wine-oleview.desktop, 1.1, 1.2 wine-regedit.desktop, 1.4, 1.5 wine-uninstaller.desktop, 1.4, 1.5 wine-wineboot.desktop, 1.3, 1.4 wine-winecfg.desktop, 1.3, 1.4 wine-winefile.desktop, 1.3, 1.4 wine-winemine.desktop, 1.3, 1.4 wine-winhelp.desktop, 1.4, 1.5 wine-wordpad.desktop, 1.1, 1.2 wine.spec, 1.123, 1.124

Andreas Bierfert awjb at fedoraproject.org
Mon May 31 13:17:19 UTC 2010


Author: awjb

Update of /cvs/pkgs/rpms/wine/devel
In directory cvs01.phx2.fedoraproject.org:/tmp/cvs-serv3586/devel

Modified Files:
	.cvsignore sources wine-notepad.desktop wine-oleview.desktop 
	wine-regedit.desktop wine-uninstaller.desktop 
	wine-wineboot.desktop wine-winecfg.desktop 
	wine-winefile.desktop wine-winemine.desktop 
	wine-winhelp.desktop wine-wordpad.desktop wine.spec 
Added Files:
	wine-fonts.patch wine-imagemagick-6.5.patch 
Log Message:
- version upgrade
- add BR for ImageMagick and icoutils
- spec cleanup
- install available icon files (#594950)
- desktop package requires wine x86-32 because of wine/wine64 rename
- put system/small fonts in right place


wine-fonts.patch:
 dlls/gdi32/freetype.c |   40 ++++++++++++++++++++--------------------
 tools/wine.inf.in     |    3 ++-
 2 files changed, 22 insertions(+), 21 deletions(-)

--- NEW FILE wine-fonts.patch ---
--- tools/wine.inf.in.orig	2010-05-26 07:41:44.000000000 +0200
+++ tools/wine.inf.in	2010-05-26 07:46:15.000000000 +0200
@@ -576,13 +576,14 @@
 HKLM,%FontSubStr%,"Courier New TUR,162",,"Courier New,162"
 HKLM,%FontSubStr%,"Helv",,"MS Sans Serif"
 HKLM,%FontSubStr%,"Helvetica",,"Arial"
-HKLM,%FontSubStr%,"MS Shell Dlg 2",,"Tahoma"
+HKLM,%FontSubStr%,"MS Shell Dlg 2",,"Liberation Sans"
 HKLM,%FontSubStr%,"Times",,"Times New Roman"
 HKLM,%FontSubStr%,"Times New Roman Baltic,186",,"Times New Roman,186"
 HKLM,%FontSubStr%,"Times New Roman CE,238",,"Times New Roman,238"
 HKLM,%FontSubStr%,"Times New Roman CYR,204",,"Times New Roman,204"
 HKLM,%FontSubStr%,"Times New Roman Greek,161",,"Times New Roman,161"
 HKLM,%FontSubStr%,"Times New Roman TUR,162",,"Times New Roman,162"
+HKLM,%FontSubStr%,"MS Sans Serif",,"Liberation Serif"
 HKLM,System\CurrentControlSet\Hardware Profiles\Current\Software\Fonts,"LogPixels",0x10003,0x00000060
 
 [MCI]

wine-imagemagick-6.5.patch:
 configure    |    4 ++--
 configure.ac |    4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

--- NEW FILE wine-imagemagick-6.5.patch ---
--- configure.orig	2010-05-25 19:44:56.000000000 +0200
+++ configure	2010-05-25 19:46:11.000000000 +0200
@@ -5132,10 +5132,10 @@
     then
       convert_version_major=`expr "$convert_version" : '.* \([0-9]*\)\.[0-9]*'`
       convert_version_minor=`expr "$convert_version" : '.* [0-9]*\.\([0-9]*\)'`
-      if test "$convert_version_major" -eq 6 -a "$convert_version_minor" -lt 6
+      if test "$convert_version_major" -eq 6 -a "$convert_version_minor" -lt 5
       then
         CONVERT=false
-        as_fn_append wine_warnings "|imagemagick version 6.6 or newer is needed to rebuild icons."
+        as_fn_append wine_warnings "|imagemagick version 6.5 or newer is needed to rebuild icons."
       fi
     fi
     if test "$CONVERT" = false
--- configure.ac.orig	2010-05-25 19:45:16.000000000 +0200
+++ configure.ac	2010-05-25 19:46:44.000000000 +0200
@@ -303,10 +303,10 @@
     then
       convert_version_major=`expr "$convert_version" : '.* \([[0-9]]*\)\.[[0-9]]*'`
       convert_version_minor=`expr "$convert_version" : '.* [[0-9]]*\.\([[0-9]]*\)'`
-      if test "$convert_version_major" -eq 6 -a "$convert_version_minor" -lt 6
+      if test "$convert_version_major" -eq 6 -a "$convert_version_minor" -lt 5
       then
         CONVERT=false
-        WINE_WARNING([imagemagick version 6.6 or newer is needed to rebuild icons.])
+        WINE_WARNING([imagemagick version 6.5 or newer is needed to rebuild icons.])
       fi
     fi
     if test "$CONVERT" = false


Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/.cvsignore,v
retrieving revision 1.85
retrieving revision 1.86
diff -u -p -r1.85 -r1.86
--- .cvsignore	10 May 2010 17:04:21 -0000	1.85
+++ .cvsignore	31 May 2010 13:17:18 -0000	1.86
@@ -1 +1 @@
-wine-1.1.44.tar.bz2
+wine-1.2-rc2.tar.bz2


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/sources,v
retrieving revision 1.86
retrieving revision 1.87
diff -u -p -r1.86 -r1.87
--- sources	10 May 2010 17:04:21 -0000	1.86
+++ sources	31 May 2010 13:17:18 -0000	1.87
@@ -1 +1 @@
-f18649bd71b9099fecad22436d239cba  wine-1.1.44.tar.bz2
+99b4511a5a005a1ef363700d482f80f1  wine-1.2-rc2.tar.bz2


Index: wine-notepad.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-notepad.desktop,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -p -r1.4 -r1.5
--- wine-notepad.desktop	24 Jun 2009 10:53:29 -0000	1.4
+++ wine-notepad.desktop	31 May 2010 13:17:18 -0000	1.5
@@ -2,6 +2,7 @@
 Name=Notepad
 Comment=Text Editor
 Exec=notepad
+Icon=notepad
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-oleview.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-oleview.desktop,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -p -r1.1 -r1.2
--- wine-oleview.desktop	24 Jun 2009 10:53:30 -0000	1.1
+++ wine-oleview.desktop	31 May 2010 13:17:18 -0000	1.2
@@ -2,6 +2,7 @@
 Name=Wine OLE View
 Comment=Windows OLE View
 Exec=wine oleview
+Icon=wine
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-regedit.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-regedit.desktop,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -p -r1.4 -r1.5
--- wine-regedit.desktop	24 Jun 2009 10:53:30 -0000	1.4
+++ wine-regedit.desktop	31 May 2010 13:17:19 -0000	1.5
@@ -2,6 +2,7 @@
 Name=Regedit
 Comment=Wine registry editor
 Exec=regedit
+Icon=regedit
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-uninstaller.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-uninstaller.desktop,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -p -r1.4 -r1.5
--- wine-uninstaller.desktop	14 May 2009 13:25:11 -0000	1.4
+++ wine-uninstaller.desktop	31 May 2010 13:17:19 -0000	1.5
@@ -2,6 +2,7 @@
 Name=Wine Software Uninstaller
 Comment=Interface to uninstall software
 Exec=wine uninstaller
+Icon=wine
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-wineboot.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-wineboot.desktop,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -p -r1.3 -r1.4
--- wine-wineboot.desktop	24 Jun 2009 10:53:30 -0000	1.3
+++ wine-wineboot.desktop	31 May 2010 13:17:19 -0000	1.4
@@ -2,6 +2,7 @@
 Name=Wine Boot
 Comment=Simulate restart
 Exec=wineboot
+Icon=wine
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-winecfg.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-winecfg.desktop,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -p -r1.3 -r1.4
--- wine-winecfg.desktop	18 Jun 2007 09:49:09 -0000	1.3
+++ wine-winecfg.desktop	31 May 2010 13:17:19 -0000	1.4
@@ -2,6 +2,7 @@
 Name=Wine Configuration
 Comment=Interface to set wine parameters
 Exec=winecfg
+Icon=winecfg
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-winefile.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-winefile.desktop,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -p -r1.3 -r1.4
--- wine-winefile.desktop	18 Jun 2007 09:49:09 -0000	1.3
+++ wine-winefile.desktop	31 May 2010 13:17:19 -0000	1.4
@@ -2,6 +2,7 @@
 Name=Wine File
 Comment=Wine File Browser
 Exec=winefile
+Icon=winefile
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-winemine.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-winemine.desktop,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -p -r1.3 -r1.4
--- wine-winemine.desktop	24 Nov 2008 22:19:32 -0000	1.3
+++ wine-winemine.desktop	31 May 2010 13:17:19 -0000	1.4
@@ -2,6 +2,7 @@
 Name=WineMine
 Comment=Wine Minesweeper 
 Exec=winemine
+Icon=winemine
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-winhelp.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-winhelp.desktop,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -p -r1.4 -r1.5
--- wine-winhelp.desktop	24 Jun 2009 10:53:30 -0000	1.4
+++ wine-winhelp.desktop	31 May 2010 13:17:19 -0000	1.5
@@ -2,6 +2,7 @@
 Name=Wine Help
 Comment=Windows Help Browser
 Exec=wine winhlp32
+Icon=winhelp
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine-wordpad.desktop
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine-wordpad.desktop,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -p -r1.1 -r1.2
--- wine-wordpad.desktop	24 Jun 2009 10:53:30 -0000	1.1
+++ wine-wordpad.desktop	31 May 2010 13:17:19 -0000	1.2
@@ -2,6 +2,7 @@
 Name=Wine Wordpad
 Comment=Text Editor
 Exec=wine wordpad
+Icon=wordpad
 Terminal=false
 Type=Application
 Encoding=UTF-8


Index: wine.spec
===================================================================
RCS file: /cvs/pkgs/rpms/wine/devel/wine.spec,v
retrieving revision 1.123
retrieving revision 1.124
diff -u -p -r1.123 -r1.124
--- wine.spec	14 May 2010 08:29:04 -0000	1.123
+++ wine.spec	31 May 2010 13:17:19 -0000	1.124
@@ -1,13 +1,13 @@
 %define no64bit 0
 Name:		wine
-Version:	1.1.44
-Release:	4%{?dist}
+Version:	1.2.0
+Release:	0.2.rc2%{?dist}
 Summary:	A Windows 16/32/64 bit emulator
 
 Group:		Applications/Emulators
 License:	LGPLv2+
 URL:		http://www.winehq.org/
-Source0:        http://ibiblio.org/pub/linux/system/emulators/wine/%{name}-%{version}.tar.bz2
+Source0:        http://ibiblio.org/pub/linux/system/emulators/wine/wine-1.2-rc2.tar.bz2
 Source1:	wine.init
 Source3:        wine-README-Fedora
 Source4:        wine-32.conf
@@ -34,6 +34,13 @@ Source300:      wine-mime-msi.desktop
 
 Patch1:         wine-rpath.patch
 
+# bugfixes
+# fix for #593140
+Patch100:       wine-fonts.patch
+
+# 
+Patch200:       wine-imagemagick-6.5.patch
+
 # explain how to use wine with pulseaudio
 # see http://bugs.winehq.org/show_bug.cgi?id=10495
 # and http://art.ified.ca/?page_id=40
@@ -105,8 +112,8 @@ BuildRequires:  gsm-devel
 BuildRequires:  openal-soft-devel
 BuildRequires:  libv4l-devel
 BuildRequires:  fontpackages-devel
-
-# noarch
+BuildRequires:  icoutils
+BuildRequires:  ImageMagick-devel
 Requires:       wine-common = %{version}-%{release}
 Requires:       wine-desktop = %{version}-%{release}
 Requires:       wine-fonts = %{version}-%{release}
@@ -195,7 +202,7 @@ Requires(post): /sbin/chkconfig, /sbin/s
 Requires(post): desktop-file-utils >= 0.8
 Requires(preun): /sbin/chkconfig, /sbin/service
 Requires(postun): desktop-file-utils >= 0.8
-Requires:       wine-core = %{version}-%{release}
+Requires:       wine-core(x86-32) = %{version}-%{release}
 Requires:       wine-common = %{version}-%{release}
 BuildArch:      noarch
 
@@ -214,6 +221,8 @@ Requires:      wine-marlett-fonts = %{ve
 #Requires:      wine-ms-sans-serif-fonts = %{version}-%{release}
 #Requires:      wine-tahoma-fonts = %{version}-%{release}
 Requires:      wine-symbol-fonts = %{version}-%{release}
+# intermediate fix for #593140
+Requires:      liberation-sans-fonts liberation-serif-fonts
 
 %description fonts
 %{summary}
@@ -400,9 +409,11 @@ This package adds an openal driver for w
 
 
 %prep
-%setup -q
+%setup -q -n %{name}-1.2-rc2
 
 %patch1
+%patch100
+%patch200
 %patch400
 %patch401 -p1
 %patch402 -p1
@@ -424,8 +435,6 @@ export CFLAGS="$RPM_OPT_FLAGS -Wno-error
         --enable-maintainer-mode \
 	--disable-tests
 
-%{__make} depend
-
 %{__make} TARGETFLAGS="" %{?_smp_mflags}
 
 %install
@@ -438,13 +447,6 @@ rm -rf %{buildroot}
 	LDCONFIG=/bin/true \
 	UPDATE_DESKTOP_DATABASE=/bin/true
 
-%ifarch %{ix86}
-# rename wine to wine32
-mv %{buildroot}%{_bindir}/wine{,32}
-# create link to wine32 if ix86
-ln -s %{_bindir}/wine32 %{buildroot}%{_bindir}/wine
-%endif
-
 mkdir -p %{buildroot}%{_sysconfdir}/wine
 
 # Allow users to launch Windows programs by just clicking on the .exe file...
@@ -461,79 +463,111 @@ install -p -m 644 %{SOURCE201} \
 
 
 # install desktop files
+mkdir -p %{buildroot}%{_datadir}/pixmaps
+install -p -m 644 programs/winemenubuilder/wine.xpm \
+ %{buildroot}%{_datadir}/pixmaps/wine.xpm
+
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/notepad/ \
+ programs/notepad/notepad.ico
+install -p -m 644 programs/notepad/notepad*png \
+ %{buildroot}%{_datadir}/pixmaps/notepad.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE100}
 
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/regedit/ \
+ programs/regedit/regedit.ico
+install -p -m 644 programs/regedit/regedit*png \
+ %{buildroot}%{_datadir}/pixmaps/regedit.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE101}
 
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE102}
 
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/winecfg/ \
+ programs/winecfg/winecfg.ico
+install -p -m 644 programs/winecfg/winecfg*png \
+ %{buildroot}%{_datadir}/pixmaps/winecfg.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE103}
 
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/winefile/ \
+ programs/winefile/winefile.ico
+install -p -m 644 programs/winefile/winefile*png \
+ %{buildroot}%{_datadir}/pixmaps/winefile.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE104}
 
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/winemine/ \
+ programs/winemine/winemine.ico
+install -p -m 644 programs/winemine/winemine*png \
+ %{buildroot}%{_datadir}/pixmaps/winemine.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE105}
 
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/winhlp32/ \
+ programs/winhlp32/winhelp.ico
+install -p -m 644 programs/winhlp32/winhelp*png \
+ %{buildroot}%{_datadir}/pixmaps/winhelp.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE106}
 
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE107}
 
+icotool -x --width=32 --height=32 --bit-depth=32 -o programs/wordpad/ \
+ programs/wordpad/wordpad.ico
+install -p -m 644 programs/wordpad/wordpad*png \
+ %{buildroot}%{_datadir}/pixmaps/wordpad.png
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE108}
 
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE109}
 
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   --delete-original \
-  $RPM_BUILD_ROOT%{_datadir}/applications/wine.desktop
+  %{buildroot}%{_datadir}/applications/wine.desktop
 
 #mime-types
 desktop-file-install \
   --vendor=fedora \
-  --dir=$RPM_BUILD_ROOT%{_datadir}/applications \
+  --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE300}
 
 
 cp %{SOURCE3} README-Fedora
 
-mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/ld.so.conf.d/
+mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d/
 
 %ifarch %{ix86}
-install -p -m644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/ld.so.conf.d/
+install -p -m644 %{SOURCE4} %{buildroot}%{_sysconfdir}/ld.so.conf.d/
 %endif
 
 %ifarch x86_64
-install -p -m644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/ld.so.conf.d/
+install -p -m644 %{SOURCE5} %{buildroot}%{_sysconfdir}/ld.so.conf.d/
 %endif
 
 # deploy pulseaudio readme
@@ -545,9 +579,11 @@ mv %{buildroot}/%{_datadir}/wine/fonts/c
 
 install -p -m 0755 -d %{buildroot}/%{_datadir}/fonts/wine-system-fonts
 mv %{buildroot}/%{_datadir}/wine/fonts/*sys.* %{buildroot}/%{_datadir}/fonts/wine-system-fonts/
+mv %{buildroot}/%{_datadir}/wine/fonts/vgas*.* %{buildroot}/%{_datadir}/fonts/wine-system-fonts/
 
 install -p -m 0755 -d %{buildroot}/%{_datadir}/fonts/wine-small-fonts
 mv %{buildroot}/%{_datadir}/wine/fonts/sma* %{buildroot}/%{_datadir}/fonts/wine-small-fonts/
+mv %{buildroot}/%{_datadir}/wine/fonts/jsma* %{buildroot}/%{_datadir}/fonts/wine-small-fonts/
 
 install -p -m 0755 -d %{buildroot}/%{_datadir}/fonts/wine-marlett-fonts
 mv %{buildroot}/%{_datadir}/wine/fonts/marlett.ttf %{buildroot}/%{_datadir}/fonts/wine-marlett-fonts/
@@ -655,13 +691,13 @@ update-desktop-database &>/dev/null || :
 
 
 %ifarch %{ix86}
-%{_bindir}/wine32
+%{_bindir}/wine
 %{_bindir}/wine-preloader
 %{_sysconfdir}/ld.so.conf.d/wine-32.conf
 %endif
 
 %ifarch x86_64
-%{_bindir}/wine
+%{_bindir}/wine64
 %{_sysconfdir}/ld.so.conf.d/wine-64.conf
 %endif
 
@@ -896,6 +932,7 @@ update-desktop-database &>/dev/null || :
 %{_libdir}/wine/rsabase.dll.so
 %{_libdir}/wine/rsaenh.dll.so
 %{_libdir}/wine/rtutils.dll.so
+%{_libdir}/wine/samlib.dll.so
 %{_libdir}/wine/sc.exe.so
 %{_libdir}/wine/sccbase.dll.so
 %{_libdir}/wine/schannel.dll.so
@@ -1075,10 +1112,11 @@ update-desktop-database &>/dev/null || :
 %{_datadir}/wine/generic.ppd
 %{_datadir}/wine/wine.inf
 %{_datadir}/wine/l_intl.nls
+%{_datadir}/pixmaps/*xpm
 
 %files fonts
 %defattr(-,root,root,-)
-%{_datadir}/wine/fonts
+%dir %{_datadir}/wine/fonts
 
 %files courier-fonts
 %defattr(-,root,root,-)
@@ -1125,6 +1163,7 @@ update-desktop-database &>/dev/null || :
 %{_datadir}/desktop-directories/Wine.directory
 %{_sysconfdir}/xdg/menus/applications-merged/wine.menu
 %{_initrddir}/wine
+%{_datadir}/pixmaps/*png
 
 # esd subpackage
 %files esd
@@ -1184,6 +1223,7 @@ update-desktop-database &>/dev/null || :
 %{_mandir}/man1/winedbg.1*
 %{_mandir}/man1/wineg++.1*
 %lang(de) %{_mandir}/de.UTF-8/man1/winemaker.1*
+%lang(fr) %{_mandir}/fr.UTF-8/man1/winemaker.1*
 %attr(0755, root, root) %dir %{_includedir}/wine
 %{_includedir}/wine/*
 %{_libdir}/*.so
@@ -1209,6 +1249,23 @@ update-desktop-database &>/dev/null || :
 %{_libdir}/wine/openal32.dll.so
 
 %changelog
+* Mon May 31 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
+- 1.2-0.2.rc2
+- version upgrade
+
+* Mon May 24 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
+- 1.2-0.1.rc1
+- upgrade to rc1
+- add BR for ImageMagick and icoutils
+- spec cleanup
+- install available icon files (#594950)
+- desktop package requires wine x86-32 because of wine/wine64 rename
+- put system/small fonts in right place
+
+* Wed May 19 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
+- 1.1.44-5
+- fix font issues
+
 * Thu May 13 2010 Andreas Bierfert <andreas.bierfert[AT]lowlatency.de>
 - 1.1.44-4
 - fix install of 32bit only wine on x86_64 via install wine.i686



More information about the scm-commits mailing list
--- dlls/gdi32/freetype.c.orig	2010-05-19 22:02:43.000000000 +0200
+++ dlls/gdi32/freetype.c	2010-05-19 23:57:27.000000000 +0200
@@ -400,7 +400,7 @@
 /* Interesting and well-known (frequently-assumed!) font names */
 static const WCHAR Lucida_Sans_Unicode[] = {'L','u','c','i','d','a',' ','S','a','n','s',' ','U','n','i','c','o','d','e',0};
 static const WCHAR Microsoft_Sans_Serif[] = {'M','i','c','r','o','s','o','f','t',' ','S','a','n','s',' ','S','e','r','i','f',0 };
-static const WCHAR Tahoma[] = {'T','a','h','o','m','a',0};
+static const WCHAR Liberation[] = {'L','i','b','e','r','a','t','i','o','n',' ','S','a','n','s',0};
 static const WCHAR MS_UI_Gothic[] = {'M','S',' ','U','I',' ','G','o','t','h','i','c',0};
 static const WCHAR SimSun[] = {'S','i','m','S','u','n',0};
 static const WCHAR Gulim[] = {'G','u','l','i','m',0};
@@ -1641,7 +1641,7 @@
     WCHAR *entry, *next;
     SYSTEM_LINKS *font_link, *system_font_link;
     CHILD_FONT *child_font;
-    static const WCHAR tahoma_ttf[] = {'t','a','h','o','m','a','.','t','t','f',0};
+    static const WCHAR liberation_ttf[] = {'L','i','b','e','r','a','t','i','o','n','S','a','n','s','-','R','e','g','u','l','a','r','.','t','t','f',0};
     static const WCHAR System[] = {'S','y','s','t','e','m',0};
     FONTSIGNATURE fs;
     Family *family;
@@ -1723,25 +1723,25 @@
         RegCloseKey(hkey);
     }
 
-    /* Explicitly add an entry for the system font, this links to Tahoma and any links
-       that Tahoma has */
+    /* Explicitly add an entry for the system font, this links to Liberation Sans and any links
+       that Liberation Sans has */
 
     system_font_link = HeapAlloc(GetProcessHeap(), 0, sizeof(*system_font_link));
     system_font_link->font_name = strdupW(System);
     list_init(&system_font_link->links);    
 
-    face = find_face_from_filename(tahoma_ttf, Tahoma);
+    face = find_face_from_filename(liberation_ttf, Liberation);
     if(face)
     {
         child_font = HeapAlloc(GetProcessHeap(), 0, sizeof(*child_font));
         child_font->face = face;
         child_font->font = NULL;
-        TRACE("Found Tahoma in %s index %ld\n", child_font->face->file, child_font->face->face_index);
+        TRACE("Found Liberation Sans in %s index %ld\n", child_font->face->file, child_font->face->face_index);
         list_add_tail(&system_font_link->links, &child_font->entry);
     }
     LIST_FOR_EACH_ENTRY(font_link, &system_links, SYSTEM_LINKS, entry)
     {
-        if(!strcmpiW(font_link->font_name, Tahoma))
+        if(!strcmpiW(font_link->font_name, Liberation))
         {
             CHILD_FONT *font_link_entry;
             LIST_FOR_EACH_ENTRY(font_link_entry, &font_link->links, CHILD_FONT, entry)
@@ -2193,21 +2193,21 @@
     /* Latin 1 (United States) */
     { 1252, 437, "vgaoem.fon", "vgafix.fon", "vgasys.fon",
       "coure.fon", "serife.fon", "smalle.fon", "sserife.fon",
-      "Tahoma","Times New Roman",
+      "Liberation Sans","Times New Roman",
       NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
       { 0 }, { 0 }, { 0 }
     },
     /* Latin 1 (Multilingual) */
     { 1252, 850, "vga850.fon", "vgafix.fon", "vgasys.fon",
       "coure.fon", "serife.fon", "smalle.fon", "sserife.fon",
-      "Tahoma","Times New Roman",  /* FIXME unverified */
+      "Liberation Sans","Times New Roman",  /* FIXME unverified */
       NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
       { 0 }, { 0 }, { 0 }
     },
     /* Eastern Europe */
     { 1250, 852, "vga852.fon", "vgafixe.fon", "vgasyse.fon",
       "couree.fon", "serifee.fon", "smallee.fon", "sserifee.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,238", "System,238",
       "Courier New,238", "MS Serif,238", "Small Fonts,238",
       "MS Sans Serif,238", "MS Sans Serif,238", "MS Serif,238",
@@ -2218,7 +2218,7 @@
     /* Cyrillic */
     { 1251, 866, "vga866.fon", "vgafixr.fon", "vgasysr.fon",
       "courer.fon", "serifer.fon", "smaller.fon", "sserifer.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,204", "System,204",
       "Courier New,204", "MS Serif,204", "Small Fonts,204",
       "MS Sans Serif,204", "MS Sans Serif,204", "MS Serif,204",
@@ -2229,7 +2229,7 @@
     /* Greek */
     { 1253, 737, "vga869.fon", "vgafixg.fon", "vgasysg.fon",
       "coureg.fon", "serifeg.fon", "smalleg.fon", "sserifeg.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,161", "System,161",
       "Courier New,161", "MS Serif,161", "Small Fonts,161",
       "MS Sans Serif,161", "MS Sans Serif,161", "MS Serif,161",
@@ -2240,7 +2240,7 @@
     /* Turkish */
     { 1254, 857, "vga857.fon", "vgafixt.fon", "vgasyst.fon",
       "couret.fon", "serifet.fon", "smallet.fon", "sserifet.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,162", "System,162",
       "Courier New,162", "MS Serif,162", "Small Fonts,162",
       "MS Sans Serif,162", "MS Sans Serif,162", "MS Serif,162",
@@ -2251,7 +2251,7 @@
     /* Hebrew */
     { 1255, 862, "vgaoem.fon", "vgaf1255.fon", "vgas1255.fon",
       "coue1255.fon", "sere1255.fon", "smae1255.fon", "ssee1255.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,177", "System,177",
       "Courier New,177", "MS Serif,177", "Small Fonts,177",
       "MS Sans Serif,177", "MS Sans Serif,177", "MS Serif,177",
@@ -2260,7 +2260,7 @@
     /* Arabic */
     { 1256, 720, "vgaoem.fon", "vgaf1256.fon", "vgas1256.fon",
       "coue1256.fon", "sere1256.fon", "smae1256.fon", "ssee1256.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,178", "System,178",
       "Courier New,178", "MS Serif,178", "Small Fonts,178",
       "MS Sans Serif,178", "MS Sans Serif,178", "MS Serif,178",
@@ -2269,7 +2269,7 @@
     /* Baltic */
     { 1257, 775, "vga775.fon", "vgaf1257.fon", "vgas1257.fon",
       "coue1257.fon", "sere1257.fon", "smae1257.fon", "ssee1257.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       "Fixedsys,186", "System,186",
       "Courier New,186", "MS Serif,186", "Small Fonts,186",
       "MS Sans Serif,186", "MS Sans Serif,186", "MS Serif,186",
@@ -2280,14 +2280,14 @@
     /* Vietnamese */
     { 1258, 1258, "vga850.fon", "vgafix.fon", "vgasys.fon",
       "coure.fon", "serife.fon", "smalle.fon", "sserife.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
       { 0 }, { 0 }, { 0 }
     },
     /* Thai */
     { 874, 874, "vga850.fon", "vgaf874.fon", "vgas874.fon",
       "coure.fon", "serife.fon", "smalle.fon", "ssee874.fon",
-      "Tahoma","Times New Roman", /* FIXME unverified */
+      "Liberation Sans","Times New Roman", /* FIXME unverified */
       NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
       { 0 }, { 0 }, { 0 }
     },
@@ -2325,7 +2325,7 @@
 {
     Lucida_Sans_Unicode,
     Microsoft_Sans_Serif,
-    Tahoma
+    Liberation
 };
 
 static const struct font_links_defaults_list
@@ -2337,7 +2337,7 @@
 } font_links_defaults_list[] =
 {
     /* Non East-Asian */
-    { Tahoma, /* FIXME unverified ordering */
+    { Liberation, /* FIXME unverified ordering */
       { MS_UI_Gothic, SimSun, Gulim, PMingLiU, NULL }
     },
     /* Below lists are courtesy of